#include <iostream>
#include <stdlib.h>
#include <limits>

extern "C" {
#include "iio.h"
}

bool read_image(const char *fname, float **I, int &nx, int &ny)
{	
	int nz;
	float *f;
	
	*I = NULL;
	
	f = iio_read_image_float_vec(fname, &nx, &ny, &nz);
	
	if(nz > 0)
	{
	    *I = new float[nx * ny];
	    
	    if(nz == 1)
	      
		for(int i = 0; i < ny; i++)
		    for(int j = 0; j < nx; j++)
			(*I)[i*nx+j] = f[(i*nx+j)];

	    else if(nz == 3)

		for(int i = 0; i < ny; i++)

		    for(int j = 0; j < nx; j++) {
			  float a = f[(i*nx+j)*nz];
			  float b = f[(i*nx+j)*nz+1];
			  float c = f[(i*nx+j)*nz+2];
			  (*I)[i*nx+j] = (a+b+c)/3;
		    }

	    delete []f;
	}

	return *I ? true : false;
}





int main(int argc, char *argv[])
{
    if(argc < 3)

        std::cout << "Usage: " << argv[0]
                  << " input_flow output_flow [factor_scale]"
                  << std::endl;
    else
    {
        int i = 1;

        //read the parameters
        const char *input_flow  = argv[i]; i++;
        const char *output_flow = argv[i]; i++;

        float factor_scale = 1.0;

        if(argc > i) { factor_scale = atof(argv[i]); i++; }

        // Leer la imagen estereo (PNG, PPM, ...)
        float *iflow = NULL;
        int nx, ny;
        read_image(input_flow, &iflow, nx, ny);
                    
        float *f = new float[nx * ny * 2];
        for (int i = 0; i < nx * ny; i++) {
        	f[2*i] = iflow[i] / factor_scale;
            f[2*i+1] = 0.0;
        }
            
        iio_save_image_float_vec(output_flow, f, nx, ny, 2);
        delete []f;

        if (iflow != NULL) delete []iflow;

        std::cout << std::endl << "DONE." << std::endl;
    }

    return 0;
}







/*

bool read_image(const char *fname, float **Ir, float **Ig, float **Ib, int &nx, int &ny)
{
	int nz;
	float *f;
	
	*Ir = *Ig = *Ib = NULL;
	
	f = iio_read_image_float_vec(fname, &nx, &ny, &nz);
	
	if(nz > 0)
	{
	    *Ir = new float[nx * ny];
	    *Ig = new float[nx * ny];
	    *Ib = new float[nx * ny];
	    
	    int dg=1, db=2;
	    
	    if(nz == 1) dg=db=0;
	    
	    for(int i = 0; i < ny; i++)
		for(int j = 0; j < nx; j++)
		{
		      (*Ir)[i*nx+j] = f[(i*nx+j)*nz];
		      (*Ig)[i*nx+j] = f[(i*nx+j)*nz+dg];
		      (*Ib)[i*nx+j] = f[(i*nx+j)*nz+db];
		}
		
	    delete []f;
	}
	
	return *Ir ? true : false;
}


bool read_flow(const char *fname, float **u, float **v, int &nx, int &ny)
{
	
	float *f;
	int nz;
	
	*u = *v = NULL;
	
	f = iio_read_image_float_vec(fname, &nx, &ny, &nz);
	
	if(nz > 0)
	{
	    *u = new float[nx * ny];
	    *v = new float[nx * ny];
    
	    int dg=1, db=2;
	    
	    if(nz == 1) dg=db=0;
	    
	    for(int i = 0; i < ny; i++)
		for(int j = 0; j < nx; j++)
		{
		      (*u)[i*nx+j] = f[(i*nx+j)*2];
		      (*v)[i*nx+j] = f[(i*nx+j)*2+1];
		}
	}
	
	return *u ? true : false;
}

*/
